# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kernel_server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13kernel_server.proto\x12\x14octopus_kernel_proto\x1a\x0c\x63ommon.proto\")\n\x12StartKernelRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"0\n\x13StartKernelResponse\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\"(\n\x11StopKernelRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"/\n\x12StopKernelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"+\n\x14RestartKernelRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"2\n\x15RestartKernelResponse\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\"3\n\x0e\x45xecuteRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x13\n\x0bkernel_name\x18\x02 \x01(\t\"\xb9\x01\n\x0f\x45xecuteResponse\x12\x45\n\x0boutput_type\x18\x01 \x01(\x0e\x32\x30.octopus_kernel_proto.ExecuteResponse.OutputType\x12\x0e\n\x06output\x18\x02 \x01(\t\"O\n\nOutputType\x12\x0e\n\nStdoutType\x10\x00\x12\x0e\n\nStderrType\x10\x01\x12\x0e\n\nResultType\x10\x02\x12\x11\n\rTracebackType\x10\x03\"\'\n\x10GetStatusRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"@\n\x11GetStatusResponse\x12\x10\n\x08is_alive\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t2\xb7\x04\n\x10KernelServerNode\x12^\n\x05start\x12(.octopus_kernel_proto.StartKernelRequest\x1a).octopus_kernel_proto.StartKernelResponse\"\x00\x12[\n\x04stop\x12\'.octopus_kernel_proto.StopKernelRequest\x1a(.octopus_kernel_proto.StopKernelResponse\"\x00\x12Z\n\x07\x65xecute\x12$.octopus_kernel_proto.ExecuteRequest\x1a%.octopus_kernel_proto.ExecuteResponse\"\x00\x30\x01\x12_\n\nget_status\x12&.octopus_kernel_proto.GetStatusRequest\x1a\'.octopus_kernel_proto.GetStatusResponse\"\x00\x12Q\n\x06upload\x12\x1f.octopus_common_proto.FileChunk\x1a\".octopus_common_proto.FileUploaded\"\x00(\x01\x12V\n\x08\x64ownload\x12%.octopus_common_proto.DownloadRequest\x1a\x1f.octopus_common_proto.FileChunk\"\x00\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kernel_server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STARTKERNELREQUEST']._serialized_start=59
  _globals['_STARTKERNELREQUEST']._serialized_end=100
  _globals['_STARTKERNELRESPONSE']._serialized_start=102
  _globals['_STARTKERNELRESPONSE']._serialized_end=150
  _globals['_STOPKERNELREQUEST']._serialized_start=152
  _globals['_STOPKERNELREQUEST']._serialized_end=192
  _globals['_STOPKERNELRESPONSE']._serialized_start=194
  _globals['_STOPKERNELRESPONSE']._serialized_end=241
  _globals['_RESTARTKERNELREQUEST']._serialized_start=243
  _globals['_RESTARTKERNELREQUEST']._serialized_end=286
  _globals['_RESTARTKERNELRESPONSE']._serialized_start=288
  _globals['_RESTARTKERNELRESPONSE']._serialized_end=338
  _globals['_EXECUTEREQUEST']._serialized_start=340
  _globals['_EXECUTEREQUEST']._serialized_end=391
  _globals['_EXECUTERESPONSE']._serialized_start=394
  _globals['_EXECUTERESPONSE']._serialized_end=579
  _globals['_EXECUTERESPONSE_OUTPUTTYPE']._serialized_start=500
  _globals['_EXECUTERESPONSE_OUTPUTTYPE']._serialized_end=579
  _globals['_GETSTATUSREQUEST']._serialized_start=581
  _globals['_GETSTATUSREQUEST']._serialized_end=620
  _globals['_GETSTATUSRESPONSE']._serialized_start=622
  _globals['_GETSTATUSRESPONSE']._serialized_end=686
  _globals['_KERNELSERVERNODE']._serialized_start=689
  _globals['_KERNELSERVERNODE']._serialized_end=1256
# @@protoc_insertion_point(module_scope)
